# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

_SNAKE_TO_CAMEL_CASE_TABLE = {
    "access_token_lifetime_minutes": "accessTokenLifetimeMinutes",
    "accessibility_error_redirect_url": "accessibilityErrorRedirectUrl",
    "accessibility_login_redirect_url": "accessibilityLoginRedirectUrl",
    "accessibility_self_service": "accessibilitySelfService",
    "account_link_action": "accountLinkAction",
    "account_link_group_includes": "accountLinkGroupIncludes",
    "acs_binding": "acsBinding",
    "acs_type": "acsType",
    "admin_roles": "adminRoles",
    "always_include_in_token": "alwaysIncludeInToken",
    "app_excludes": "appExcludes",
    "app_id": "appId",
    "app_includes": "appIncludes",
    "app_settings_json": "appSettingsJson",
    "array_enums": "arrayEnums",
    "array_one_ofs": "arrayOneOfs",
    "array_type": "arrayType",
    "assertion_signed": "assertionSigned",
    "attribute_statements": "attributeStatements",
    "auth_provider": "authProvider",
    "auth_server_id": "authServerId",
    "auth_url": "authUrl",
    "authn_context_class_ref": "authnContextClassRef",
    "authorization_binding": "authorizationBinding",
    "authorization_url": "authorizationUrl",
    "auto_key_rotation": "autoKeyRotation",
    "auto_submit_toolbar": "autoSubmitToolbar",
    "button_field": "buttonField",
    "button_selector": "buttonSelector",
    "claim_type": "claimType",
    "client_basic_secret": "clientBasicSecret",
    "client_id": "clientId",
    "client_secret": "clientSecret",
    "client_uri": "clientUri",
    "client_whitelists": "clientWhitelists",
    "consent_method": "consentMethod",
    "consent_type": "consentType",
    "cost_center": "costCenter",
    "country_code": "countryCode",
    "credentials_last_rotated": "credentialsLastRotated",
    "credentials_next_rotation": "credentialsNextRotation",
    "credentials_rotation_mode": "credentialsRotationMode",
    "credentials_scheme": "credentialsScheme",
    "custom_client_id": "customClientId",
    "custom_profile_attributes": "customProfileAttributes",
    "default_language": "defaultLanguage",
    "default_relay_state": "defaultRelayState",
    "delete_when_absent": "deleteWhenAbsent",
    "deprovisioned_action": "deprovisionedAction",
    "digest_algorithm": "digestAlgorithm",
    "display_name": "displayName",
    "dynamic_locations": "dynamicLocations",
    "email_recovery": "emailRecovery",
    "employee_number": "employeeNumber",
    "entity_key": "entityKey",
    "entity_url": "entityUrl",
    "expires_at": "expiresAt",
    "expression_type": "expressionType",
    "expression_value": "expressionValue",
    "external_name": "externalName",
    "extra_field_selector": "extraFieldSelector",
    "extra_field_value": "extraFieldValue",
    "fido_u2f": "fidoU2f",
    "fido_webauthn": "fidoWebauthn",
    "first_name": "firstName",
    "google_otp": "googleOtp",
    "grant_type_whitelists": "grantTypeWhitelists",
    "grant_types": "grantTypes",
    "group_assignments": "groupAssignments",
    "group_blacklists": "groupBlacklists",
    "group_filter_type": "groupFilterType",
    "group_id": "groupId",
    "group_memberships": "groupMemberships",
    "group_whitelists": "groupWhitelists",
    "groups_action": "groupsAction",
    "groups_assignments": "groupsAssignments",
    "groups_attribute": "groupsAttribute",
    "groups_filters": "groupsFilters",
    "groups_includeds": "groupsIncludeds",
    "hide_ios": "hideIos",
    "hide_web": "hideWeb",
    "honor_force_authn": "honorForceAuthn",
    "honorific_prefix": "honorificPrefix",
    "honorific_suffix": "honorificSuffix",
    "http_post_binding": "httpPostBinding",
    "http_redirect_binding": "httpRedirectBinding",
    "idp_id": "idpId",
    "idp_issuer": "idpIssuer",
    "idp_type": "idpType",
    "inline_hook_id": "inlineHookId",
    "issuer_mode": "issuerMode",
    "issuer_url": "issuerUrl",
    "jwks_binding": "jwksBinding",
    "jwks_url": "jwksUrl",
    "key_id": "keyId",
    "key_name": "keyName",
    "key_years_valid": "keyYearsValid",
    "last_name": "lastName",
    "login_uri": "loginUri",
    "logo_uri": "logoUri",
    "manager_id": "managerId",
    "match_attribute": "matchAttribute",
    "match_type": "matchType",
    "max_clock_skew": "maxClockSkew",
    "max_length": "maxLength",
    "metadata_publish": "metadataPublish",
    "mfa_lifetime": "mfaLifetime",
    "mfa_prompt": "mfaPrompt",
    "mfa_remember_device": "mfaRememberDevice",
    "mfa_required": "mfaRequired",
    "middle_name": "middleName",
    "min_length": "minLength",
    "mobile_phone": "mobilePhone",
    "name_format": "nameFormat",
    "network_connection": "networkConnection",
    "network_excludes": "networkExcludes",
    "network_includes": "networkIncludes",
    "nick_name": "nickName",
    "okta_call": "oktaCall",
    "okta_otp": "oktaOtp",
    "okta_password": "oktaPassword",
    "okta_push": "oktaPush",
    "okta_question": "oktaQuestion",
    "okta_sms": "oktaSms",
    "omit_secret": "omitSecret",
    "one_ofs": "oneOfs",
    "optional_field1": "optionalField1",
    "optional_field1_value": "optionalField1Value",
    "optional_field2": "optionalField2",
    "optional_field2_value": "optionalField2Value",
    "optional_field3": "optionalField3",
    "optional_field3_value": "optionalField3Value",
    "password_auto_unlock_minutes": "passwordAutoUnlockMinutes",
    "password_change": "passwordChange",
    "password_dictionary_lookup": "passwordDictionaryLookup",
    "password_exclude_first_name": "passwordExcludeFirstName",
    "password_exclude_last_name": "passwordExcludeLastName",
    "password_exclude_username": "passwordExcludeUsername",
    "password_expire_warn_days": "passwordExpireWarnDays",
    "password_field": "passwordField",
    "password_history_count": "passwordHistoryCount",
    "password_max_age_days": "passwordMaxAgeDays",
    "password_max_lockout_attempts": "passwordMaxLockoutAttempts",
    "password_min_age_minutes": "passwordMinAgeMinutes",
    "password_min_length": "passwordMinLength",
    "password_min_lowercase": "passwordMinLowercase",
    "password_min_number": "passwordMinNumber",
    "password_min_symbol": "passwordMinSymbol",
    "password_min_uppercase": "passwordMinUppercase",
    "password_reset": "passwordReset",
    "password_selector": "passwordSelector",
    "password_show_lockout_failures": "passwordShowLockoutFailures",
    "password_unlock": "passwordUnlock",
    "platform_includes": "platformIncludes",
    "policy_id": "policyId",
    "policy_uri": "policyUri",
    "post_logout_redirect_uris": "postLogoutRedirectUris",
    "postal_address": "postalAddress",
    "preconfigured_app": "preconfiguredApp",
    "preferred_language": "preferredLanguage",
    "primary_phone": "primaryPhone",
    "profile_master": "profileMaster",
    "profile_url": "profileUrl",
    "protocol_type": "protocolType",
    "provider_id": "providerId",
    "provisioning_action": "provisioningAction",
    "question_min_length": "questionMinLength",
    "question_recovery": "questionRecovery",
    "raw_status": "rawStatus",
    "recovery_answer": "recoveryAnswer",
    "recovery_email_token": "recoveryEmailToken",
    "recovery_question": "recoveryQuestion",
    "redirect_uris": "redirectUris",
    "refresh_token_lifetime_minutes": "refreshTokenLifetimeMinutes",
    "refresh_token_window_minutes": "refreshTokenWindowMinutes",
    "request_compressed": "requestCompressed",
    "request_integration": "requestIntegration",
    "request_signature_algorithm": "requestSignatureAlgorithm",
    "request_signature_scope": "requestSignatureScope",
    "response_signature_algorithm": "responseSignatureAlgorithm",
    "response_signature_scope": "responseSignatureScope",
    "response_signed": "responseSigned",
    "response_types": "responseTypes",
    "reveal_password": "revealPassword",
    "rsa_token": "rsaToken",
    "scope_whitelists": "scopeWhitelists",
    "second_email": "secondEmail",
    "session_idle": "sessionIdle",
    "session_lifetime": "sessionLifetime",
    "session_persistent": "sessionPersistent",
    "shared_password": "sharedPassword",
    "shared_username": "sharedUsername",
    "sign_on_mode": "signOnMode",
    "sign_on_redirect_url": "signOnRedirectUrl",
    "sign_on_url": "signOnUrl",
    "signature_algorithm": "signatureAlgorithm",
    "skip_unlock": "skipUnlock",
    "sms_recovery": "smsRecovery",
    "source_id": "sourceId",
    "source_name": "sourceName",
    "source_type": "sourceType",
    "sp_issuer": "spIssuer",
    "sso_binding": "ssoBinding",
    "sso_destination": "ssoDestination",
    "sso_url": "ssoUrl",
    "street_address": "streetAddress",
    "subject_filter": "subjectFilter",
    "subject_formats": "subjectFormats",
    "subject_match_attribute": "subjectMatchAttribute",
    "subject_match_type": "subjectMatchType",
    "subject_name_id_format": "subjectNameIdFormat",
    "subject_name_id_template": "subjectNameIdTemplate",
    "suspended_action": "suspendedAction",
    "symantec_vip": "symantecVip",
    "target_id": "targetId",
    "target_name": "targetName",
    "target_type": "targetType",
    "token_binding": "tokenBinding",
    "token_endpoint_auth_method": "tokenEndpointAuthMethod",
    "token_url": "tokenUrl",
    "tos_uri": "tosUri",
    "url_regex": "urlRegex",
    "user_blacklists": "userBlacklists",
    "user_id": "userId",
    "user_identifier_attribute": "userIdentifierAttribute",
    "user_identifier_patterns": "userIdentifierPatterns",
    "user_identifier_type": "userIdentifierType",
    "user_info_binding": "userInfoBinding",
    "user_info_url": "userInfoUrl",
    "user_name_template": "userNameTemplate",
    "user_name_template_suffix": "userNameTemplateSuffix",
    "user_name_template_type": "userNameTemplateType",
    "user_type": "userType",
    "user_whitelists": "userWhitelists",
    "username_field": "usernameField",
    "username_selector": "usernameSelector",
    "username_template": "usernameTemplate",
    "users_excludeds": "usersExcludeds",
    "value_type": "valueType",
    "x5t_s256": "x5tS256",
    "yubikey_token": "yubikeyToken",
    "zip_code": "zipCode",
}

_CAMEL_TO_SNAKE_CASE_TABLE = {
    "accessTokenLifetimeMinutes": "access_token_lifetime_minutes",
    "accessibilityErrorRedirectUrl": "accessibility_error_redirect_url",
    "accessibilityLoginRedirectUrl": "accessibility_login_redirect_url",
    "accessibilitySelfService": "accessibility_self_service",
    "accountLinkAction": "account_link_action",
    "accountLinkGroupIncludes": "account_link_group_includes",
    "acsBinding": "acs_binding",
    "acsType": "acs_type",
    "adminRoles": "admin_roles",
    "alwaysIncludeInToken": "always_include_in_token",
    "appExcludes": "app_excludes",
    "appId": "app_id",
    "appIncludes": "app_includes",
    "appSettingsJson": "app_settings_json",
    "arrayEnums": "array_enums",
    "arrayOneOfs": "array_one_ofs",
    "arrayType": "array_type",
    "assertionSigned": "assertion_signed",
    "attributeStatements": "attribute_statements",
    "authProvider": "auth_provider",
    "authServerId": "auth_server_id",
    "authUrl": "auth_url",
    "authnContextClassRef": "authn_context_class_ref",
    "authorizationBinding": "authorization_binding",
    "authorizationUrl": "authorization_url",
    "autoKeyRotation": "auto_key_rotation",
    "autoSubmitToolbar": "auto_submit_toolbar",
    "buttonField": "button_field",
    "buttonSelector": "button_selector",
    "claimType": "claim_type",
    "clientBasicSecret": "client_basic_secret",
    "clientId": "client_id",
    "clientSecret": "client_secret",
    "clientUri": "client_uri",
    "clientWhitelists": "client_whitelists",
    "consentMethod": "consent_method",
    "consentType": "consent_type",
    "costCenter": "cost_center",
    "countryCode": "country_code",
    "credentialsLastRotated": "credentials_last_rotated",
    "credentialsNextRotation": "credentials_next_rotation",
    "credentialsRotationMode": "credentials_rotation_mode",
    "credentialsScheme": "credentials_scheme",
    "customClientId": "custom_client_id",
    "customProfileAttributes": "custom_profile_attributes",
    "defaultLanguage": "default_language",
    "defaultRelayState": "default_relay_state",
    "deleteWhenAbsent": "delete_when_absent",
    "deprovisionedAction": "deprovisioned_action",
    "digestAlgorithm": "digest_algorithm",
    "displayName": "display_name",
    "dynamicLocations": "dynamic_locations",
    "emailRecovery": "email_recovery",
    "employeeNumber": "employee_number",
    "entityKey": "entity_key",
    "entityUrl": "entity_url",
    "expiresAt": "expires_at",
    "expressionType": "expression_type",
    "expressionValue": "expression_value",
    "externalName": "external_name",
    "extraFieldSelector": "extra_field_selector",
    "extraFieldValue": "extra_field_value",
    "fidoU2f": "fido_u2f",
    "fidoWebauthn": "fido_webauthn",
    "firstName": "first_name",
    "googleOtp": "google_otp",
    "grantTypeWhitelists": "grant_type_whitelists",
    "grantTypes": "grant_types",
    "groupAssignments": "group_assignments",
    "groupBlacklists": "group_blacklists",
    "groupFilterType": "group_filter_type",
    "groupId": "group_id",
    "groupMemberships": "group_memberships",
    "groupWhitelists": "group_whitelists",
    "groupsAction": "groups_action",
    "groupsAssignments": "groups_assignments",
    "groupsAttribute": "groups_attribute",
    "groupsFilters": "groups_filters",
    "groupsIncludeds": "groups_includeds",
    "hideIos": "hide_ios",
    "hideWeb": "hide_web",
    "honorForceAuthn": "honor_force_authn",
    "honorificPrefix": "honorific_prefix",
    "honorificSuffix": "honorific_suffix",
    "httpPostBinding": "http_post_binding",
    "httpRedirectBinding": "http_redirect_binding",
    "idpId": "idp_id",
    "idpIssuer": "idp_issuer",
    "idpType": "idp_type",
    "inlineHookId": "inline_hook_id",
    "issuerMode": "issuer_mode",
    "issuerUrl": "issuer_url",
    "jwksBinding": "jwks_binding",
    "jwksUrl": "jwks_url",
    "keyId": "key_id",
    "keyName": "key_name",
    "keyYearsValid": "key_years_valid",
    "lastName": "last_name",
    "loginUri": "login_uri",
    "logoUri": "logo_uri",
    "managerId": "manager_id",
    "matchAttribute": "match_attribute",
    "matchType": "match_type",
    "maxClockSkew": "max_clock_skew",
    "maxLength": "max_length",
    "metadataPublish": "metadata_publish",
    "mfaLifetime": "mfa_lifetime",
    "mfaPrompt": "mfa_prompt",
    "mfaRememberDevice": "mfa_remember_device",
    "mfaRequired": "mfa_required",
    "middleName": "middle_name",
    "minLength": "min_length",
    "mobilePhone": "mobile_phone",
    "nameFormat": "name_format",
    "networkConnection": "network_connection",
    "networkExcludes": "network_excludes",
    "networkIncludes": "network_includes",
    "nickName": "nick_name",
    "oktaCall": "okta_call",
    "oktaOtp": "okta_otp",
    "oktaPassword": "okta_password",
    "oktaPush": "okta_push",
    "oktaQuestion": "okta_question",
    "oktaSms": "okta_sms",
    "omitSecret": "omit_secret",
    "oneOfs": "one_ofs",
    "optionalField1": "optional_field1",
    "optionalField1Value": "optional_field1_value",
    "optionalField2": "optional_field2",
    "optionalField2Value": "optional_field2_value",
    "optionalField3": "optional_field3",
    "optionalField3Value": "optional_field3_value",
    "passwordAutoUnlockMinutes": "password_auto_unlock_minutes",
    "passwordChange": "password_change",
    "passwordDictionaryLookup": "password_dictionary_lookup",
    "passwordExcludeFirstName": "password_exclude_first_name",
    "passwordExcludeLastName": "password_exclude_last_name",
    "passwordExcludeUsername": "password_exclude_username",
    "passwordExpireWarnDays": "password_expire_warn_days",
    "passwordField": "password_field",
    "passwordHistoryCount": "password_history_count",
    "passwordMaxAgeDays": "password_max_age_days",
    "passwordMaxLockoutAttempts": "password_max_lockout_attempts",
    "passwordMinAgeMinutes": "password_min_age_minutes",
    "passwordMinLength": "password_min_length",
    "passwordMinLowercase": "password_min_lowercase",
    "passwordMinNumber": "password_min_number",
    "passwordMinSymbol": "password_min_symbol",
    "passwordMinUppercase": "password_min_uppercase",
    "passwordReset": "password_reset",
    "passwordSelector": "password_selector",
    "passwordShowLockoutFailures": "password_show_lockout_failures",
    "passwordUnlock": "password_unlock",
    "platformIncludes": "platform_includes",
    "policyId": "policy_id",
    "policyUri": "policy_uri",
    "postLogoutRedirectUris": "post_logout_redirect_uris",
    "postalAddress": "postal_address",
    "preconfiguredApp": "preconfigured_app",
    "preferredLanguage": "preferred_language",
    "primaryPhone": "primary_phone",
    "profileMaster": "profile_master",
    "profileUrl": "profile_url",
    "protocolType": "protocol_type",
    "providerId": "provider_id",
    "provisioningAction": "provisioning_action",
    "questionMinLength": "question_min_length",
    "questionRecovery": "question_recovery",
    "rawStatus": "raw_status",
    "recoveryAnswer": "recovery_answer",
    "recoveryEmailToken": "recovery_email_token",
    "recoveryQuestion": "recovery_question",
    "redirectUris": "redirect_uris",
    "refreshTokenLifetimeMinutes": "refresh_token_lifetime_minutes",
    "refreshTokenWindowMinutes": "refresh_token_window_minutes",
    "requestCompressed": "request_compressed",
    "requestIntegration": "request_integration",
    "requestSignatureAlgorithm": "request_signature_algorithm",
    "requestSignatureScope": "request_signature_scope",
    "responseSignatureAlgorithm": "response_signature_algorithm",
    "responseSignatureScope": "response_signature_scope",
    "responseSigned": "response_signed",
    "responseTypes": "response_types",
    "revealPassword": "reveal_password",
    "rsaToken": "rsa_token",
    "scopeWhitelists": "scope_whitelists",
    "secondEmail": "second_email",
    "sessionIdle": "session_idle",
    "sessionLifetime": "session_lifetime",
    "sessionPersistent": "session_persistent",
    "sharedPassword": "shared_password",
    "sharedUsername": "shared_username",
    "signOnMode": "sign_on_mode",
    "signOnRedirectUrl": "sign_on_redirect_url",
    "signOnUrl": "sign_on_url",
    "signatureAlgorithm": "signature_algorithm",
    "skipUnlock": "skip_unlock",
    "smsRecovery": "sms_recovery",
    "sourceId": "source_id",
    "sourceName": "source_name",
    "sourceType": "source_type",
    "spIssuer": "sp_issuer",
    "ssoBinding": "sso_binding",
    "ssoDestination": "sso_destination",
    "ssoUrl": "sso_url",
    "streetAddress": "street_address",
    "subjectFilter": "subject_filter",
    "subjectFormats": "subject_formats",
    "subjectMatchAttribute": "subject_match_attribute",
    "subjectMatchType": "subject_match_type",
    "subjectNameIdFormat": "subject_name_id_format",
    "subjectNameIdTemplate": "subject_name_id_template",
    "suspendedAction": "suspended_action",
    "symantecVip": "symantec_vip",
    "targetId": "target_id",
    "targetName": "target_name",
    "targetType": "target_type",
    "tokenBinding": "token_binding",
    "tokenEndpointAuthMethod": "token_endpoint_auth_method",
    "tokenUrl": "token_url",
    "tosUri": "tos_uri",
    "urlRegex": "url_regex",
    "userBlacklists": "user_blacklists",
    "userId": "user_id",
    "userIdentifierAttribute": "user_identifier_attribute",
    "userIdentifierPatterns": "user_identifier_patterns",
    "userIdentifierType": "user_identifier_type",
    "userInfoBinding": "user_info_binding",
    "userInfoUrl": "user_info_url",
    "userNameTemplate": "user_name_template",
    "userNameTemplateSuffix": "user_name_template_suffix",
    "userNameTemplateType": "user_name_template_type",
    "userType": "user_type",
    "userWhitelists": "user_whitelists",
    "usernameField": "username_field",
    "usernameSelector": "username_selector",
    "usernameTemplate": "username_template",
    "usersExcludeds": "users_excludeds",
    "valueType": "value_type",
    "x5tS256": "x5t_s256",
    "yubikeyToken": "yubikey_token",
    "zipCode": "zip_code",
}
